package javax.wvcm;

/**
 * The location of a resource.
 * All methods in this interface are client-side only,
 * i.e. no communication with the server is required.
 */
public interface Location {
	
   /**
    * Return the string value for this Location.
    */
   public String string();

   /**
    * Return the Location of the child with the specified
    * binding name in the folder at this Location.
    * The string value of the Location of the child 
    * is commonly created by appending a "/" and the name
    * of the child to the string value of this Location.
    */
   public Location child(String bindingName) throws WvcmException;

   /**
    * Return the Location of the parent folder of the resource
    * at this Location.  If this Location
    * is the root of the namespace, <code>null</code> is returned.
    * The string value of the Location of the parent folder
    * is commonly created by stripping off the last segment
    * beginning with a "/" character of this Location.
    */
   public Location parent();

   /**
    * Return a proxy for the activity at this Location.
    */
   public Activity activity();

   /**
    * Return a proxy for the folder at this Location.
    */
   public Folder<? extends ControllableResource> folder();

   /**
    * Return a proxy for the resource at this Location.
    */
   public Resource resource();

   /**
    * Return a proxy for the controllable resource at this Location.
    */
   public ControllableResource controllableResource();

   /**
    * Return a proxy for the workspace at this location.
    */
   public Workspace workspace();

}
